@@ -3,12 +3,13 @@ package TaskPipe::JobManager;
 use Moose;
 use Carp;
 use Proc::ProcessTable;
-use TaskPipe::TorManager;
 use TaskPipe::JobManager::Settings;
 use Log::Log4perl;
 use DateTime;
 use Try::Tiny;
 use File::Path 'rmtree';
+use Data::Dumper;
+use TaskPipe::PortManager;
 
 #has job_id => (is => 'rw', isa => 'Int');
 
@@ -19,35 +20,11 @@ has run_info => (is => 'rw', isa => 'TaskPipe::RunInfo', default => sub{
 has name => (is => 'rw', isa => 'Str');
 has project => (is => 'rw', isa => 'Str');
 
-has exempt => (is => 'rw', isa => 'Bool', default => 0);
-
-# Allow these commands to proceed without being recorded on job table even if database connect fails
-# This is necessary because we need to be able to execute these commands before the db is set up
-has exemptions => (is => 'ro', isa => 'ArrayRef', default => sub{[
-    'Setup',
-    'GenerateSchema',
-    'DeployTables'
-]}); 
-
-
-
-
 has gm => (is => 'rw', isa => 'TaskPipe::SchemaManager', lazy => 1, default => sub{
     my ($self) = @_;
 
     my $gm = TaskPipe::SchemaManager->new( scope => 'global' );
-
-    try {
-        $gm->connect_schema;
-    } catch {
-        if ( grep { $_ eq $self->name } @{$self->exemptions} ){
-            warn "Could not register job as database is unavailable. Proceeding without job_id: this command is exempt";
-            $self->exempt(1);
-        } else {
-            die "$_\n";
-        }
-    };
-
+    $gm->connect_schema;
     return $gm;
 });
 
@@ -59,16 +36,32 @@ has port_manager => (is => 'ro', isa => 'TaskPipe::PortManager', lazy => 1, defa
     TaskPipe::PortManager->new( gm => $_[0]->gm );
 });
 
+has proc_lookup => (is => 'rw', isa => 'HashRef', lazy => 1, builder => 'build_proc_lookup');
 
 
 
+sub build_proc_lookup{
+    my ($self) = @_;
+
+    my $t = Proc::ProcessTable->new;
+
+    my $lookup = {};
+    foreach my $p ( @{$t->table} ){ 
+        $lookup->{ $p->pid } = $p->cmndline;
+    }
+    return $lookup;
+}
+
+
 
 
 sub init_job{
     my ($self) = @_;
 
-    $self->gm; # force connection attempt
-    return if $self->exempt;
+    my $logger = Log::Log4perl->get_logger;
+
+    return if $self->settings->job_tracking ne 'register';
+    $self->gm; #:force connection attempt FIXME
 
     my $insert = {};
     foreach my $param ( qw(name project) ){
@@ -79,13 +72,17 @@ sub init_job{
     $insert->{pid} = $$;
     $insert->{orig_cmd} = "@{$self->run_info->orig_cmd}";
     $insert->{created_dt} = DateTime->now;
+    $insert->{shell} = $self->run_info->shell;
 
     $self->clean_tables;
 
+    $logger->debug("Recording start of job");
     my $job_row = $self->gm->table('job')->create($insert);
     confess "Job failed: Unable to register job in database" unless $job_row;
 
     $self->run_info->job_id( $job_row->id );
+    $logger->debug("Job ".$job_row->id." started");
+
     return $job_row->id;
 } 
        
@@ -94,14 +91,15 @@ sub init_job{
 sub end_job{
     my ($self) = @_;
 
-    return if $self->exempt;
+    return if $self->settings->job_tracking ne 'register';
 
     confess "Need a job_id" unless defined $self->run_info->job_id;
 
     $self->stop_spawned;
 
     $self->gm->schema->txn_do( sub{
-        $self->gm->table('thread')->search({
+        $self->gm->table('spawned')->search({
+            process_name => "thread",
             job_id => $self->run_info->job_id
         })->delete_all;
         $self->gm->table('job')->search({
@@ -115,15 +113,20 @@ sub end_job{
 sub stop_spawned {
     my ($self, $job_id) = @_;
 
+    my $logger = Log::Log4perl->get_logger;
+
     $job_id ||= $self->run_info->job_id;
 
+
     my $spawned_rs = $self->gm->table('spawned')->search({
         job_id => $job_id
     });
 
     while( my $spawned = $spawned_rs->next ){
 
-        kill 'KILL', $spawned->pid;
+        my $pid = $spawned->pid;
+        $logger->debug("Stopping process $pid");
+        kill 'KILL', $pid;
         if ( $spawned->temp_dir ){
             rmtree( $spawned->temp_dir );
         }
@@ -139,9 +142,24 @@ sub stop_spawned {
 sub daemonize{
     my $self = shift;
 
+    $self->gm->table('job')->find({
+        id => $self->run_info->job_id
+    })->update({
+        shell => $self->run_info->shell
+    });
+
     $self->fork_safely and exit;
     POSIX::setsid();
-    $self->fork_safely and exit;
+    my $new_pid = $self->fork_safely;
+ 
+    if ( $new_pid ){
+        $self->gm->table('job')->find({
+            id => $self->run_info->job_id
+        })->update({
+            pid => $new_pid
+        });
+        exit;
+    }
 
     umask 0;
     chdir '/';
@@ -169,31 +187,29 @@ sub process_active{
 
     my $logger = Log::Log4perl->get_logger;
 
-    my $t = Proc::ProcessTable->new;
-
     my $active = 0;
 
-    foreach my $p ( @{$t->table} ){ 
-        if ( $p->pid eq $pid ){
-            $active = 1;
+    if ( $self->proc_lookup->{$pid} ){
+
+        $active = 1;
+        $active = 0 unless $self->proc_lookup->{$pid} =~ /taskpipe/;
 
-            # sanity check to make sure this really is the
-            # original process
-            my @orig_cmd = split( /\s+/, $orig_cmd );
-            foreach my $arg ( @orig_cmd ){
-                $active = 0 unless $p->cmndline =~ /$arg/;
-            }
-        }
     }
 
     return $active;
 }
 
+            
+
+
 
 sub clean_tables{
     my $self = shift;
 
-    my $procs_rs = $self->gm->table('job')->search;    
+    my $logger = Log::Log4perl->get_logger;
+    $logger->debug("Cleaning job table...");
+
+    my $procs_rs = $self->gm->table('job')->search({});;    
 
     # remove table rows from job and thread which no longer have active processes
     while( my $proc_row = $procs_rs->next ){
@@ -201,20 +217,22 @@ sub clean_tables{
         my $parent_active = 0;
         my $threads_active = 0;
 
-        $parent_active = $self->process_active($proc_row->pid, $proc_row->orig_cmd);
+        $parent_active = $self->process_active($proc_row->pid);
 
         # if parent not active, it doesn't mean the process is not running - 
         # the parent could have died but left children active
         my $threads_rs;
         if ( ! $parent_active ){
 
-            $threads_rs = $self->gm->table('thread')->search({
+            $threads_rs = $self->gm->table('spawned')->search({
+                process_name => 'thread',
                 job_id => $proc_row->id
             });
 
             while( my $thread = $threads_rs->next ){
                 if ( $thread->pid && $self->process_active($thread->pid,$proc_row->orig_cmd)){
                     $threads_active = 1;
+                    last;
                 }
             }
         }
@@ -226,12 +244,16 @@ sub clean_tables{
             $proc_row->delete;
         }
     }
+
+    $logger->debug("Done cleaning job table");
 }
 
 
 sub stop_job{
     my ($self,$job_id) = @_;
 
+    my $logger = Log::Log4perl->get_logger;
+
     confess "job_id must be provided" unless defined $job_id;
 
     $self->clean_tables;
@@ -240,7 +262,8 @@ sub stop_job{
     $rs{job} = $self->gm->table('job')->search({
             id => $job_id
     });
-    $rs{thread} = $self->gm->table('thread')->search({
+    $rs{thread} = $self->gm->table('spawned')->search({
+        process_name => 'thread',
         job_id => $job_id
     });
 
@@ -252,28 +275,31 @@ sub stop_job{
     do {
 
         $active = 0;
-        my $t = Proc::ProcessTable->new;
 
         my $procs_rs = $self->gm->table('job')->search({
             id => $job_id
         });
    
+        $self->proc_lookup( $self->build_proc_lookup );
         while( my $proc_row = $procs_rs->next ){
 
-            if ( $self->process_active($proc_row->pid, $proc_row->orig_cmd) ){
+            if ( $self->process_active($proc_row->pid) ){
+                $logger->debug("Killing job pid ".$proc_row->pid);
                 $active = 1;
                 kill 'KILL', $proc_row->pid;
             }
 
-            my $threads_rs = $self->gm->table('thread')->search({
+            my $threads_rs = $self->gm->table('spawned')->search({
+                process_name => 'thread',
                 job_id => $proc_row->id
             });
 
             while( my $thread = $threads_rs->next ){
 
-                if ( $thread->pid && $self->process_active($thread->pid, $proc_row->orig_cmd) ){
+                if ( $thread->pid && $self->process_active($thread->pid) ){
+                    $logger->debug("Killing thread pid ".$thread->pid);
                     $active = 1;
-                    kill 'KILL', $thread->pid
+                    kill 'KILL', $thread->pid;
                 }
             }
         }
@@ -285,8 +311,6 @@ sub stop_job{
     
     $self->stop_spawned( $job_id );
 
-    $self->clean_tables;
-
 }
 
 
@@ -295,7 +319,7 @@ sub stop_job{
 sub list_jobs{
     my ($self,@cols) = @_;
 
-    $self->clean_tables;
+    #$self->clean_tables;
 
     my $jobs_rs = $self->gm->table('job')->search;
 
