@@ -18,7 +18,7 @@ coerce 'StrArrayRef', from 'Str', via {
 
 =head1 NAME
 
-TaskPipe::Role::MooseType_StrArrayRef
+TaskPipe::Role::MooseType_StrArrayRef - array ref represented as a string type constraint
 
 =head1 DESCRIPTION
 
